@@ -1,9 +1,9 @@
-
+from beaker._compat import string_type
 
 # (c) 2005 Ian Bicking and contributors; written for Paste (http://pythonpaste.org)
 # Licensed under the MIT license: http://www.opensource.org/licenses/mit-license.php
 def asbool(obj):
-    if isinstance(obj, (str, unicode)):
+    if isinstance(obj, string_type):
         obj = obj.strip().lower()
         if obj in ['true', 'yes', 'on', 'y', 't', '1']:
             return True
@@ -16,7 +16,7 @@ def asbool(obj):
 
 
 def aslist(obj, sep=None, strip=True):
-    if isinstance(obj, (str, unicode)):
+    if isinstance(obj, string_type):
         lst = obj.split(sep)
         if strip:
             lst = [v.strip() for v in lst]
